# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.2.0] - 2024-02-16

### Added

- Metadata hook: add suport for additional-classifiers property #10

### Fixed

- Build hook: fix issue with extract_items when target_path is in a subfolder #11
- Tests: ensure tests are also ok when ran from a fork or outside any Git structure

## [0.1.0] - 2024-02-05

### Added

- Initial release
